# reactive-core

[![PyPI - Version](https://img.shields.io/pypi/v/reactive-core.svg)](https://pypi.org/project/reactive-core)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/reactive-core.svg)](https://pypi.org/project/reactive-core)

---

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install reactive-core
```
